[Author Prev][Author Next][Thread Prev][Thread Next][Author Index][Thread Index]

gEDA-cvs: pcb.git: branch: master updated (2756468cf3ada09fa768bae8287b73fe79b41a8a)



The branch, master has been updated
       via  2756468cf3ada09fa768bae8287b73fe79b41a8a (commit)
       via  97963eb2ad6a4ea2e82e2084653bf52d0dedbc1d (commit)
       via  d882cbe3a56ba41e7723d8da1b57255d361075ac (commit)
       via  6714f5ff18afbf12c2a059482d747d15f250d68e (commit)
       via  2e46d5a7a626f703d868d25670af33b0c2afff17 (commit)
       via  99ac52a605256bf60089d3177ff268d9fccf83ad (commit)
       via  b2f7f75a375ca20350891f464283018677763a61 (commit)
       via  42930014efab78eb5ddb06ea1ef9053c4c7bb13e (commit)
       via  86585c7eb9c35faa9ea310c241e80edb038c2055 (commit)
       via  2265df977e20edf832f56c74e78fca1e15b45555 (commit)
       via  5f9832e8b50bd56dd56d28391dc6cb8c7be8a0d9 (commit)
       via  05f663f3905d3dde859fefa1f614c29d67428539 (commit)
       via  7fa6e8145b3a9e2b85b42a2bae12d55fe0005ae1 (commit)
       via  ec76a0d17c1baea2dd83a6a67b6fe48aee74b547 (commit)
       via  d5fd3e348da36c4fb10100b0cc5e218069c309c9 (commit)
       via  a17c8a99d84ba8408ffe6173813a982016545cba (commit)
       via  e4a4a0740d6b648ce5026bef1261726037f90163 (commit)
       via  9dab8d5519bcb752d91d3e4647bbc2356ed80830 (commit)
       via  cadcc01668cd9de9629992bcfc9d28f910738662 (commit)
       via  8a764804b6c1af050552ba79ec284a2021d55157 (commit)
       via  f9119256366eb114f4dd30a62fa1aa95cd9ffb72 (commit)
       via  8f3cf398616a634cb85c40b7295dcfec5fbe70e5 (commit)
       via  4f81df61732f5328a0d66cabc53503fd745c8bc9 (commit)
       via  0c66ee758d318111b5ec867f0ba89f4fab0a6601 (commit)
       via  3c47897d8c8d151ae76203f1bb49270d9a2d747e (commit)
      from  bdf06d189aa089b01e13753c3164d35c1aaa8d5e (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.


=========
 Summary
=========

 src/Makefile.am           |    2 +
 src/action.c              |  116 ++++++++++++++++++++++----------------------
 src/autoroute.c           |    2 +
 src/buffer.c              |    3 +-
 src/change.c              |    2 -
 src/djopt.c               |    2 +
 src/file.c                |    2 +-
 src/flags.c               |    7 ++-
 src/gts/edge.c            |    2 +-
 src/gts/pgraph.c          |    4 +-
 src/hid.h                 |    2 +-
 src/hid/batch/batch.c     |   25 +++++++---
 src/hid/common/actions.h  |    7 +++
 src/hid/common/hidinit.h  |    6 ++
 src/hid/common/hidnogui.c |    2 +-
 src/hid/gcode/gcode.c     |    4 +-
 src/hid/gerber/gerber.c   |    3 +-
 src/hid/gtk/gtkhid-main.c |    2 +-
 src/hid/gtk/gui-dialog.c  |    2 +-
 src/hid/gtk/gui.h         |    2 +-
 src/hid/lesstif/dialogs.c |   54 ++++++++++----------
 src/hid/lesstif/lesstif.h |    2 +-
 src/hid/lesstif/main.c    |   20 ++++----
 src/hid/lesstif/menu.c    |    6 +-
 src/hid/lesstif/netlist.c |   14 +++---
 src/hid/lesstif/styles.c  |    2 +-
 src/hid/lpr/lpr.c         |    3 +-
 src/hid/nelma/nelma.c     |    4 +-
 src/hid/png/png.c         |    4 +-
 src/hid/ps/eps.c          |    3 +-
 src/hid/ps/ps.c           |    3 +-
 src/main.c                |    6 +--
 src/misc.c                |    4 +-
 src/misc.h                |    4 +-
 src/mymem.c               |    2 +-
 src/mymem.h               |    2 +-
 src/parse_l.l             |    2 +
 src/res_lex.l             |    1 +
 src/rtree.c               |    4 +-
 src/toporouter.c          |    9 ++--
 40 files changed, 188 insertions(+), 158 deletions(-)
 create mode 100644 src/hid/common/actions.h
 create mode 100644 src/hid/common/hidinit.h


=================
 Commit Messages
=================

commit 2756468cf3ada09fa768bae8287b73fe79b41a8a
Author: Peter Clifton <pcjc2@xxxxxxxxx>
Commit: Peter Clifton <pcjc2@xxxxxxxxx>

    action.c: Mark some strings as translateable in ActionImport()

:100644 100644 34d54e2... 07b2752... M	src/action.c

commit 97963eb2ad6a4ea2e82e2084653bf52d0dedbc1d
Author: Peter Clifton <pcjc2@xxxxxxxxx>
Commit: Peter Clifton <pcjc2@xxxxxxxxx>

    Make the strings passed to AttributePutToList and MyStrdup (const char *)
    
    Silences some compiler warnings when using const char * strings.

:100644 100644 b1d4304... 34b18cb... M	src/misc.c
:100644 100644 82bd194... 776e309... M	src/misc.h
:100644 100644 59f8f8d... 13863c1... M	src/mymem.c
:100644 100644 81dff7a... fdfd7e6... M	src/mymem.h

commit d882cbe3a56ba41e7723d8da1b57255d361075ac
Author: Peter Clifton <pcjc2@xxxxxxxxx>
Commit: Peter Clifton <pcjc2@xxxxxxxxx>

    hid/lesstif: Revert some Boolean->bool type changes as required by Xt* APIs
    
    This is a partial revert of commit ad5eb5a165442be38624aa622beeb57dc1d2afbd
    
    For consistency, I have also reverted the changes of True->true and
    False->false when calling  X11 APIs.

:100644 100644 6c7a2de... a56e3a3... M	src/hid/lesstif/dialogs.c
:100644 100644 5caec02... 76dce1a... M	src/hid/lesstif/main.c
:100644 100644 9983d42... aca306d... M	src/hid/lesstif/menu.c
:100644 100644 7d31197... ee6d723... M	src/hid/lesstif/netlist.c
:100644 100644 fb9d3b3... d3dcdaa... M	src/hid/lesstif/styles.c

commit 6714f5ff18afbf12c2a059482d747d15f250d68e
Author: Peter Clifton <pcjc2@xxxxxxxxx>
Commit: Peter Clifton <pcjc2@xxxxxxxxx>

    hid/lesstif: Use an intervening size_t casts to aovid compiler warnings
    
    This is to avoid the compiler warning us what we already know.. that we
    are passing an integer value cast into what might be a different sized
    pointer. (On 64 bit builds).

:100644 100644 b3cc375... 6c7a2de... M	src/hid/lesstif/dialogs.c

commit 2e46d5a7a626f703d868d25670af33b0c2afff17
Author: Peter Clifton <pcjc2@xxxxxxxxx>
Commit: Peter Clifton <pcjc2@xxxxxxxxx>

    hid/batch: Add some missing header files for prototypes

:100644 100644 8d53d8c... 9715c09... M	src/hid/batch/batch.c

commit 99ac52a605256bf60089d3177ff268d9fccf83ad
Author: Peter Clifton <pcjc2@xxxxxxxxx>
Commit: Peter Clifton <pcjc2@xxxxxxxxx>

    hid/common: Provide a header to define hid_parse_command_line()
    
    Avoids having each caller having to pull it in with an extern declaration.

:100644 100644 ef72012... a0f1c50... M	src/Makefile.am
:100644 100644 6bc0e58... 8d53d8c... M	src/hid/batch/batch.c
:000000 100644 0000000... bd1174f... A	src/hid/common/hidinit.h
:100644 100644 7a52a7c... f1bdcea... M	src/hid/gcode/gcode.c
:100644 100644 e2d9c57... 1f6341b... M	src/hid/gerber/gerber.c
:100644 100644 aa696be... ac3e2db... M	src/hid/lpr/lpr.c
:100644 100644 c53ce05... 5f6ebc7... M	src/hid/nelma/nelma.c
:100644 100644 5c52768... 32639c8... M	src/hid/png/png.c
:100644 100644 1b85b7d... 83ce780... M	src/hid/ps/eps.c
:100644 100644 3e72b81... 814e23e... M	src/hid/ps/ps.c

commit b2f7f75a375ca20350891f464283018677763a61
Author: Peter Clifton <pcjc2@xxxxxxxxx>
Commit: Peter Clifton <pcjc2@xxxxxxxxx>

    hid/common: Provide a header file to define print_actions()
    
    Avoids having each caller having to pull it in with an extern declaration.

:100644 100644 e719268... ef72012... M	src/Makefile.am
:100644 100644 cfa4e5a... 6bc0e58... M	src/hid/batch/batch.c
:000000 100644 0000000... 1cc6f24... A	src/hid/common/actions.h
:100644 100644 ba8c959... 923e0ee... M	src/main.c

commit 42930014efab78eb5ddb06ea1ef9053c4c7bb13e
Author: Peter Clifton <pcjc2@xxxxxxxxx>
Commit: Peter Clifton <pcjc2@xxxxxxxxx>

    Fix function prototypes and dummy return values for batch HID
    
    Most of these are dummy functions, but we should get the prototypes
    right! Also, return 0 from dummy functions which are supposed to return
    an integer.
    
    Fixes various compiler warnings.

:100644 100644 7db8a54... cfa4e5a... M	src/hid/batch/batch.c

commit 86585c7eb9c35faa9ea310c241e80edb038c2055
Author: Peter Clifton <pcjc2@xxxxxxxxx>
Commit: Peter Clifton <pcjc2@xxxxxxxxx>

    HID: Make arguments to the prompt_for method const char *, not char *
    
    Avoids compiler warnings calling gui->prompt_for() with a const char *

:100644 100644 dd34b8e... 94734ba... M	src/hid.h
:100644 100644 f3b7d3c... 7db8a54... M	src/hid/batch/batch.c
:100644 100644 d5dc9e1... 6111ec3... M	src/hid/common/hidnogui.c
:100644 100644 7d59672... a3947d0... M	src/hid/gtk/gtkhid-main.c
:100644 100644 ec91233... 1f6b11a... M	src/hid/gtk/gui-dialog.c
:100644 100644 7686106... 4ad6cdc... M	src/hid/gtk/gui.h
:100644 100644 544a718... b3cc375... M	src/hid/lesstif/dialogs.c
:100644 100644 54e4ced... 3bc822b... M	src/hid/lesstif/lesstif.h

commit 2265df977e20edf832f56c74e78fca1e15b45555
Author: Peter Clifton <pcjc2@xxxxxxxxx>
Commit: Peter Clifton <pcjc2@xxxxxxxxx>

    Rename "r" variables used in calls to GetValue() to be more descriptive
    
    A purely cosmetic change.

:100644 100644 b8707d1... 34d54e2... M	src/action.c

commit 5f9832e8b50bd56dd56d28391dc6cb8c7be8a0d9
Author: Peter Clifton <pcjc2@xxxxxxxxx>
Commit: Peter Clifton <pcjc2@xxxxxxxxx>

    action.c: Fix data types in GetValue calls
    
    We passed an (int *) rather than a (bool *) in ActionImport() and
    parse_layout_attribute_units()

:100644 100644 8d5931a... b8707d1... M	src/action.c

commit 05f663f3905d3dde859fefa1f614c29d67428539
Author: Peter Clifton <pcjc2@xxxxxxxxx>
Commit: Peter Clifton <pcjc2@xxxxxxxxx>

    Change unmodifed parameters to GetValue to const char *
    
    Silences some compiler warnings in action.c

:100644 100644 76b05c0... b1d4304... M	src/misc.c
:100644 100644 bb88a21... 82bd194... M	src/misc.h

commit 7fa6e8145b3a9e2b85b42a2bae12d55fe0005ae1
Author: Peter Clifton <pcjc2@xxxxxxxxx>
Commit: Peter Clifton <pcjc2@xxxxxxxxx>

    autoroute.c: #if 0 out an unused static function add_clearance()
    
    Silences compiler warning.

:100644 100644 ea97d01... 9ccab97... M	src/autoroute.c

commit ec76a0d17c1baea2dd83a6a67b6fe48aee74b547
Author: Peter Clifton <pcjc2@xxxxxxxxx>
Commit: Peter Clifton <pcjc2@xxxxxxxxx>

    djopt.c: #if 0 out an unused static function nudge_corner()
    
    Silences a compiler warning.

:100644 100644 800e574... b5d9c39... M	src/djopt.c

commit d5fd3e348da36c4fb10100b0cc5e218069c309c9
Author: Peter Clifton <pcjc2@xxxxxxxxx>
Commit: Peter Clifton <pcjc2@xxxxxxxxx>

    buffer.c: Declare variables before code in ActionFreeRotateBuffer()
    
    Avoids compiler warning "ISO C90 forbids mixed declarations and code"

:100644 100644 bec918f... f9d6f5a... M	src/buffer.c

commit a17c8a99d84ba8408ffe6173813a982016545cba
Author: Peter Clifton <pcjc2@xxxxxxxxx>
Commit: Peter Clifton <pcjc2@xxxxxxxxx>

    change.c: Remove unused variable in ChangeElementText()

:100644 100644 5546f1f... df7f454... M	src/change.c

commit e4a4a0740d6b648ce5026bef1261726037f90163
Author: Peter Clifton <pcjc2@xxxxxxxxx>
Commit: Peter Clifton <pcjc2@xxxxxxxxx>

    Remove unused variables in ActionElementList() and ActionImport()

:100644 100644 ba9ca44... 8d5931a... M	src/action.c

commit 9dab8d5519bcb752d91d3e4647bbc2356ed80830
Author: Peter Clifton <pcjc2@xxxxxxxxx>
Commit: Peter Clifton <pcjc2@xxxxxxxxx>

    Add missing return value in ActionImport()

:100644 100644 f52fcf4... ba9ca44... M	src/action.c

commit cadcc01668cd9de9629992bcfc9d28f910738662
Author: Peter Clifton <pcjc2@xxxxxxxxx>
Commit: Peter Clifton <pcjc2@xxxxxxxxx>

    Silence used function warning for __r_tree_is_good() (Non-debug builds)
    
    __r_tree_is_good() and its helper functions are only used when debugging,
    and are called from assert() macros. If "NDEBUG" is defined, these expand
    to nothing, and the function is not called.
    
    Wrap __r_tree_is_good() and its helper, __r_tree_node_is_good() with
    #ifndef NDEBUG

:100644 100644 a6fe712... f44672c... M	src/rtree.c

commit 8a764804b6c1af050552ba79ec284a2021d55157
Author: Peter Clifton <pcjc2@xxxxxxxxx>
Commit: Peter Clifton <pcjc2@xxxxxxxxx>

    file.c: The "elapsed" variable in LoadPCB is debugging only
    
    Silence compiler warning by moving it inside the #ifdef DEBUG

:100644 100644 6893379... aff5073... M	src/file.c

commit f9119256366eb114f4dd30a62fa1aa95cd9ffb72
Author: Peter Clifton <pcjc2@xxxxxxxxx>
Commit: Peter Clifton <pcjc2@xxxxxxxxx>

    flags.c: Avoid compiler warning when casting our OffsetOf value
    
    Strictly, our OffsetOf calculation "could" return a number as large as the
    pointer size on the system - so the compiler will complain when we squash
    it directly into an int. Casting via a size_t will avoid the warning.
    
    Our structure offsets are small, so this is safe - if somewhat ugly.

:100644 100644 c33cfb6... 499e59e... M	src/flags.c

commit 8f3cf398616a634cb85c40b7295dcfec5fbe70e5
Author: Peter Clifton <pcjc2@xxxxxxxxx>
Commit: Peter Clifton <pcjc2@xxxxxxxxx>

    Toporouter: Comment unused debug variable
    
    Silences compiler warning

:100644 100644 0ad26b5... 41fd4b1... M	src/toporouter.c

commit 4f81df61732f5328a0d66cabc53503fd745c8bc9
Author: Peter Clifton <pcjc2@xxxxxxxxx>
Commit: Peter Clifton <pcjc2@xxxxxxxxx>

    gts: Comment some unused variables left as placeholders
    
    Silences compiler warnings

:100644 100644 2c13c1e... 6d1f619... M	src/gts/pgraph.c

commit 0c66ee758d318111b5ec867f0ba89f4fab0a6601
Author: Peter Clifton <pcjc2@xxxxxxxxx>
Commit: Peter Clifton <pcjc2@xxxxxxxxx>

    gts: Add cast to silence compiler warning

:100644 100644 47754de... fde7d87... M	src/gts/edge.c

commit 3c47897d8c8d151ae76203f1bb49270d9a2d747e
Author: Peter Clifton <pcjc2@xxxxxxxxx>
Commit: Peter Clifton <pcjc2@xxxxxxxxx>

    *.l: Add #define YY_NO_INPUT to avoid defining unused "input()" function
    
    Silences compiler warnings

:100644 100644 b1b67a8... c9d96c8... M	src/parse_l.l
:100644 100644 0525aed... 5e08666... M	src/res_lex.l

=========
 Changes
=========

commit 2756468cf3ada09fa768bae8287b73fe79b41a8a
Author: Peter Clifton <pcjc2@xxxxxxxxx>
Commit: Peter Clifton <pcjc2@xxxxxxxxx>

    action.c: Mark some strings as translateable in ActionImport()

diff --git a/src/action.c b/src/action.c
index 34d54e2..07b2752 100644
--- a/src/action.c
+++ b/src/action.c
@@ -7613,7 +7613,7 @@ ActionImport (int argc, char **argv, int x, int y)
       if (!ds)
 	{
 	  const char *as = AttributeGet (PCB, "import::disperse");
-	  ds = gui->prompt_for("Enter dispersion:", as ? as : "0");
+	  ds = gui->prompt_for(_("Enter dispersion:"), as ? as : "0");
 	}
       if (units)
 	{
@@ -7661,7 +7661,7 @@ ActionImport (int argc, char **argv, int x, int y)
 	}
       else
 	{
-	  Message ("Bad syntax for Import(setnewpoint)");
+	  Message (_("Bad syntax for Import(setnewpoint)"));
 	  return 1;
 	}
 

commit 97963eb2ad6a4ea2e82e2084653bf52d0dedbc1d
Author: Peter Clifton <pcjc2@xxxxxxxxx>
Commit: Peter Clifton <pcjc2@xxxxxxxxx>

    Make the strings passed to AttributePutToList and MyStrdup (const char *)
    
    Silences some compiler warnings when using const char * strings.

diff --git a/src/misc.c b/src/misc.c
index b1d4304..34b18cb 100644
--- a/src/misc.c
+++ b/src/misc.c
@@ -1892,7 +1892,7 @@ AttributeGetFromList (AttributeListType *list, char *name)
 }
 
 int
-AttributePutToList (AttributeListType *list, char *name, char *value, int replace)
+AttributePutToList (AttributeListType *list, const char *name, const char *value, int replace)
 {
   int i;
 
diff --git a/src/misc.h b/src/misc.h
index 82bd194..776e309 100644
--- a/src/misc.h
+++ b/src/misc.h
@@ -86,7 +86,7 @@ char *AttributeGetFromList (AttributeListType *list, char *name);
 /* Adds an attribute to the list.  If the attribute already exists,
    whether it's replaced or a second copy added depends on
    REPLACE.  Returns non-zero if an existing attribute was replaced.  */
-int AttributePutToList (AttributeListType *list, char *name, char *value, int replace);
+int AttributePutToList (AttributeListType *list, const char *name, const char *value, int replace);
 /* Simplistic version: Takes a pointer to an object, looks up attributes in it.  */
 #define AttributeGet(OBJ,name) AttributeGetFromList (&(OBJ->Attributes), name)
 /* Simplistic version: Takes a pointer to an object, sets attributes in it.  */
diff --git a/src/mymem.c b/src/mymem.c
index 59f8f8d..13863c1 100644
--- a/src/mymem.c
+++ b/src/mymem.c
@@ -718,7 +718,7 @@ MyRealloc (void *Ptr, size_t Size, const char *Text)
  * allocates memory for a new string, does some error processing
  */
 char *
-MyStrdup (char *S, const char *Text)
+MyStrdup (const char *S, const char *Text)
 {
   char *p = NULL;
 
diff --git a/src/mymem.h b/src/mymem.h
index 81dff7a..fdfd7e6 100644
--- a/src/mymem.h
+++ b/src/mymem.h
@@ -98,7 +98,7 @@ void **GetPointerMemory (PointerListTypePtr);
 void *MyCalloc (size_t, size_t, const char *);
 void *MyMalloc (size_t, const char *);
 void *MyRealloc (void *, size_t, const char *);
-char *MyStrdup (char *s, const char *);
+char *MyStrdup (const char *s, const char *);
 /* void MyFree (void **); */
 #define MYFREE(x) do { SaveFree(x); (x)=NULL; } while (0)
 void FreePolygonMemory (PolygonTypePtr);

commit d882cbe3a56ba41e7723d8da1b57255d361075ac
Author: Peter Clifton <pcjc2@xxxxxxxxx>
Commit: Peter Clifton <pcjc2@xxxxxxxxx>

    hid/lesstif: Revert some Boolean->bool type changes as required by Xt* APIs
    
    This is a partial revert of commit ad5eb5a165442be38624aa622beeb57dc1d2afbd
    
    For consistency, I have also reverted the changes of True->true and
    False->false when calling  X11 APIs.

diff --git a/src/hid/lesstif/dialogs.c b/src/hid/lesstif/dialogs.c
index 6c7a2de..a56e3a3 100644
--- a/src/hid/lesstif/dialogs.c
+++ b/src/hid/lesstif/dialogs.c
@@ -135,7 +135,7 @@ Load (int argc, char **argv, int x, int y)
 
   n = 0;
   stdarg (XmNpattern, pattern);
-  stdarg (XmNmustMatch, true);
+  stdarg (XmNmustMatch, True);
   stdarg (XmNselectionLabelString, xms_load);
   XtSetValues (fsb, args, n);
 
@@ -188,7 +188,7 @@ LoadVendor (int argc, char **argv, int x, int y)
 
   n = 0;
   stdarg (XmNpattern, pattern);
-  stdarg (XmNmustMatch, true);
+  stdarg (XmNmustMatch, True);
   stdarg (XmNselectionLabelString, xms_loadv);
   XtSetValues (fsb, args, n);
 
@@ -255,7 +255,7 @@ Save (int argc, char **argv, int x, int y)
 
   n = 0;
   stdarg (XmNpattern, pattern);
-  stdarg (XmNmustMatch, false);
+  stdarg (XmNmustMatch, False);
   stdarg (XmNselectionLabelString, xms_save);
   XtSetValues (fsb, args, n);
 
@@ -325,7 +325,7 @@ lesstif_logv (const char *fmt, va_list ap)
       Widget clear_button, dismiss_button;
 
       n = 0;
-      stdarg (XmNautoUnmanage, false);
+      stdarg (XmNautoUnmanage, False);
       stdarg (XmNwidth, 600);
       stdarg (XmNheight, 200);
       stdarg (XmNtitle, "PCB Log");
@@ -349,9 +349,9 @@ lesstif_logv (const char *fmt, va_list ap)
 		     (XtCallbackProc) log_dismiss, 0);
 
       n = 0;
-      stdarg (XmNeditable, false);
+      stdarg (XmNeditable, False);
       stdarg (XmNeditMode, XmMULTI_LINE_EDIT);
-      stdarg (XmNcursorPositionVisible, true);
+      stdarg (XmNcursorPositionVisible, True);
       stdarg (XmNtopAttachment, XmATTACH_FORM);
       stdarg (XmNleftAttachment, XmATTACH_FORM);
       stdarg (XmNrightAttachment, XmATTACH_FORM);
@@ -474,7 +474,7 @@ lesstif_confirm_dialog (char *msg, ...)
   wait_for_dialog (confirm_dialog);
 
   n = 0;
-  stdarg (XmNdefaultPosition, false);
+  stdarg (XmNdefaultPosition, False);
   XtSetValues (confirm_dialog, args, n);
 
   return ok;
@@ -511,16 +511,16 @@ lesstif_report_dialog (char *title, char *msg)
 	return;
 
       n = 0;
-      stdarg (XmNautoUnmanage, false);
+      stdarg (XmNautoUnmanage, False);
       stdarg (XmNwidth, 600);
       stdarg (XmNheight, 200);
       stdarg (XmNtitle, title);
       report_form = XmCreateFormDialog (mainwind, "report", args, n);
 
       n = 0;
-      stdarg (XmNeditable, false);
+      stdarg (XmNeditable, False);
       stdarg (XmNeditMode, XmMULTI_LINE_EDIT);
-      stdarg (XmNcursorPositionVisible, false);
+      stdarg (XmNcursorPositionVisible, False);
       stdarg (XmNtopAttachment, XmATTACH_FORM);
       stdarg (XmNleftAttachment, XmATTACH_FORM);
       stdarg (XmNrightAttachment, XmATTACH_FORM);
@@ -560,7 +560,7 @@ lesstif_prompt_for (const char *msg, const char *default_string)
   if (prompt_dialog == 0)
     {
       n = 0;
-      stdarg (XmNautoUnmanage, false);
+      stdarg (XmNautoUnmanage, False);
       stdarg (XmNtitle, "PCB Prompt");
       prompt_dialog = XmCreateFormDialog (mainwind, "prompt", args, n);
 
@@ -578,7 +578,7 @@ lesstif_prompt_for (const char *msg, const char *default_string)
       stdarg (XmNbottomAttachment, XmATTACH_WIDGET);
       stdarg (XmNleftAttachment, XmATTACH_FORM);
       stdarg (XmNrightAttachment, XmATTACH_FORM);
-      stdarg (XmNeditable, true);
+      stdarg (XmNeditable, True);
       prompt_text = XmCreateText (prompt_dialog, "text", args, n);
       XtManageChild (prompt_text);
       XtAddCallback (prompt_text, XmNactivateCallback,
@@ -752,20 +752,20 @@ lesstif_attribute_dialog (HID_Attribute * attrs,
 	  break;
 	case HID_String:
 	  stdarg (XmNcolumns, 40);
-	  stdarg (XmNresizeWidth, true);
+	  stdarg (XmNresizeWidth, True);
 	  stdarg (XmNvalue, results[i].str_value);
 	  wl[i] = XmCreateTextField (form, attrs[i].name, args, n);
 	  break;
 	case HID_Integer:
 	  stdarg (XmNcolumns, 13);
-	  stdarg (XmNresizeWidth, true);
+	  stdarg (XmNresizeWidth, True);
 	  sprintf (buf, "%d", results[i].int_value);
 	  stdarg (XmNvalue, buf);
 	  wl[i] = XmCreateTextField (form, attrs[i].name, args, n);
 	  break;
 	case HID_Real:
 	  stdarg (XmNcolumns, 16);
-	  stdarg (XmNresizeWidth, true);
+	  stdarg (XmNresizeWidth, True);
 	  sprintf (buf, "%g", results[i].real_value);
 	  stdarg (XmNvalue, buf);
 	  wl[i] = XmCreateTextField (form, attrs[i].name, args, n);
@@ -1269,7 +1269,7 @@ AdjustSizes (int argc, char **argv, int x, int y)
       stdarg (XmNmarginHeight, 3);
       stdarg (XmNhorizontalSpacing, 3);
       stdarg (XmNverticalSpacing, 3);
-      stdarg (XmNautoUnmanage, false);
+      stdarg (XmNautoUnmanage, False);
       stdarg (XmNtitle, "Board Sizes");
       sizes_dialog = XmCreateFormDialog (mainwind, "sizes", args, n);
 
@@ -1640,8 +1640,8 @@ EditLayerGroups (int argc, char **argv, int x, int y)
 	      stdarg (XmNbottomPosition, (i + 1) * MAX_LAYER);
 	      stdarg (XmNlabelString, XmStringCreateLocalized (" "));
 	      stdarg (XmNspacing, 0);
-	      stdarg (XmNvisibleWhenOff, true);
-	      stdarg (XmNfillOnSelect, true);
+	      stdarg (XmNvisibleWhenOff, True);
+	      stdarg (XmNfillOnSelect, True);
 	      stdarg (XmNshadowThickness, 0);
 	      stdarg (XmNmarginWidth, 0);
 	      stdarg (XmNmarginHeight, 0);
@@ -1794,14 +1794,14 @@ lesstif_attributes_need_rows (int new_max)
 		     (XtPointer) (size_t) attr_max_rows);
 
       n = 0;
-      stdarg (XmNresizeWidth, true);
+      stdarg (XmNresizeWidth, True);
       attr_row[attr_max_rows].w_name = XmCreateTextField (f_top, "name", args, n);
       XtManageChild (attr_row[attr_max_rows].w_name);
       XtAddCallback (attr_row[attr_max_rows].w_name, XmNvalueChangedCallback,
 		     (XtCallbackProc) fiddle_with_bb_layout, NULL);
 
       n = 0;
-      stdarg (XmNresizeWidth, true);
+      stdarg (XmNresizeWidth, True);
       attr_row[attr_max_rows].w_value = XmCreateTextField (f_top, "value", args, n);
       XtManageChild (attr_row[attr_max_rows].w_value);
       XtAddCallback (attr_row[attr_max_rows].w_value, XmNvalueChangedCallback,
@@ -1897,7 +1897,7 @@ lesstif_attributes_dialog (char *owner, AttributeListType *attrs_list)
   if (attr_dialog == NULL)
     {
       n = 0;
-      stdarg (XmNautoUnmanage, false);
+      stdarg (XmNautoUnmanage, False);
       stdarg (XmNtitle, owner);
       stdarg (XmNwidth, 400);
       stdarg (XmNheight, 300);
@@ -2049,7 +2049,7 @@ ImportGUI (int argc, char **argv, int x, int y)
 
   n = 0;
   stdarg (XmNpattern, xms_sch);
-  stdarg (XmNmustMatch, true);
+  stdarg (XmNmustMatch, True);
   stdarg (XmNselectionLabelString, xms_import);
   XtSetValues (fsb, args, n);
 
diff --git a/src/hid/lesstif/main.c b/src/hid/lesstif/main.c
index 5caec02..76dce1a 100644
--- a/src/hid/lesstif/main.c
+++ b/src/hid/lesstif/main.c
@@ -664,7 +664,7 @@ command_callback (Widget w, XtPointer uptr, XmTextVerifyCallbackStruct * cbs)
 }
 
 static void
-command_event_handler (Widget w, XtPointer p, XEvent * e, bool * cont)
+command_event_handler (Widget w, XtPointer p, XEvent * e, Boolean * cont)
 {
   char buf[10];
   KeySym sym;
@@ -680,7 +680,7 @@ command_event_handler (Widget w, XtPointer p, XEvent * e, bool * cont)
 	  XtUnmanageChild (m_cmd);
 	  XtUnmanageChild (m_cmd_label);
 	  XmTextSetString (w, "");
-	  *cont = false;
+	  *cont = False;
 	  break;
 	}
       break;
@@ -1294,7 +1294,7 @@ mod_changed (XKeyEvent * e, int set)
 }
 
 static void
-work_area_input (Widget w, XtPointer v, XEvent * e, bool * ctd)
+work_area_input (Widget w, XtPointer v, XEvent * e, Boolean * ctd)
 {
   static int pressed_button = 0;
   static int ignore_release = 0;
@@ -1673,7 +1673,7 @@ work_area_first_expose (Widget work_area, void *me,
       XRenderColor a = {0, 0, 0, 0x8000};
 
       pale_pixmap = XCreatePixmap (display, window, 1, 1, 8);
-      pa.repeat = true;
+      pa.repeat = True;
       pale_picture = XRenderCreatePicture (display, pale_pixmap,
 			    XRenderFindStandardFormat(display, PictStandardA8),
 			    CPRepeat, &pa);
@@ -1813,7 +1813,7 @@ lesstif_do_export (HID_Attr_Val * options)
   XtManageChild (hscroll);
 
   n = 0;
-  stdarg (XmNresize, true);
+  stdarg (XmNresize, True);
   stdarg (XmNresizePolicy, XmRESIZE_ANY);
   messages = XmCreateForm (mainwind, "messages", args, n);
   XtManageChild (messages);
@@ -1908,7 +1908,7 @@ typedef union
   char *s;
 } val_union;
 
-static bool
+static Boolean
 cvtres_string_to_double (Display * d, XrmValue * args, Cardinal * num_args,
 			 XrmValue * from, XrmValue * to,
 			 XtPointer * converter_data)
@@ -1920,7 +1920,7 @@ cvtres_string_to_double (Display * d, XrmValue * args, Cardinal * num_args,
   else
     to->addr = (XPointer) & rv;
   to->size = sizeof (rv);
-  return true;
+  return True;
 }
 
 static void
@@ -2110,7 +2110,7 @@ lesstif_parse_arguments (int *argc, char ***argv)
   XmAddWMProtocolCallback (appwidget, close_atom,
 			   (XtCallbackProc) mainwind_delete_cb, 0);
 
-  /*  XSynchronize(display, true); */
+  /*  XSynchronize(display, True); */
 
   XtGetApplicationResources (appwidget, new_values, new_resources,
 			     rmax, 0, 0);
@@ -2400,7 +2400,7 @@ lesstif_update_status_line ()
 static int idle_proc_set = 0;
 static int need_redraw = 0;
 
-static bool
+static Boolean
 idle_proc (XtPointer dummy)
 {
   if (need_redraw)
@@ -2794,7 +2794,7 @@ idle_proc (XtPointer dummy)
 
   show_crosshair (1);
   idle_proc_set = 0;
-  return true;
+  return True;
 }
 
 void
diff --git a/src/hid/lesstif/menu.c b/src/hid/lesstif/menu.c
index 9983d42..aca306d 100644
--- a/src/hid/lesstif/menu.c
+++ b/src/hid/lesstif/menu.c
@@ -271,7 +271,7 @@ LayersChanged (int argc, char **argv, int x, int y)
 	    {
 	      stdarg (XmNforeground, bg_color);
 	      stdarg (XmNbackground, fg_colors[i]);
-	      stdarg (XmNset, current_layer == i ? true : false);
+	      stdarg (XmNset, current_layer == i ? True : False);
 	    }
 	  XtSetValues (lb->w[i], args, n);
 
@@ -398,7 +398,7 @@ layerpick_button_callback (Widget w, int layer,
       if (!lb->is_pick)
 	continue;
       for (i = 0; i < LB_NUMPICK; i++)
-	XmToggleButtonSetState (lb->w[i], layer == i, false);
+	XmToggleButtonSetState (lb->w[i], layer == i, False);
     }
   switch (layer)
     {
@@ -1305,7 +1305,7 @@ add_resource_to_menu (Widget menu, Resource * node, XtCallbackProc callback)
 
 		if (resource_value (node->v[i].subres, "set"))
 		  {
-		    stdarg (XmNset, true);
+		    stdarg (XmNset, True);
 		  }
 		stdarg (XmNindicatorType, XmONE_OF_MANY);
 		btn = XmCreateToggleButton (menu, "menubutton", args, n);
diff --git a/src/hid/lesstif/netlist.c b/src/hid/lesstif/netlist.c
index 7d31197..ee6d723 100644
--- a/src/hid/lesstif/netlist.c
+++ b/src/hid/lesstif/netlist.c
@@ -89,7 +89,7 @@ netlist_select (Widget w, void *v, XmListCallbackStruct * cbs)
   str = XmStringCreateLocalized (name);
   XmListReplaceItemsPos (netlist_list, &str, 1, pos);
   XmStringFree (str);
-  XmListSelectPos (netlist_list, pos, false);
+  XmListSelectPos (netlist_list, pos, False);
 }
 
 static void
@@ -175,7 +175,7 @@ nbcb_std_callback (Widget w, Std_Nbcb_Func v, XmPushButtonCallbackStruct * cbs)
 {
   int *posl, posc, i;
   XmString **items, **selected;
-  if (XmListGetSelectedPos (netlist_list, &posl, &posc) == false)
+  if (XmListGetSelectedPos (netlist_list, &posl, &posc) == False)
     return;
   if (v == nbcb_find)
     hid_actionl ("connection", "reset", NULL);
@@ -314,7 +314,7 @@ build_netlist_dialog ()
   n = 0;
   stdarg (XmNresizePolicy, XmRESIZE_GROW);
   stdarg (XmNtitle, "Netlists");
-  stdarg (XmNautoUnmanage, false);
+  stdarg (XmNautoUnmanage, False);
   netlist_dialog = XmCreateFormDialog (mainwind, "netlist", args, n);
 
   n = 0;
@@ -435,15 +435,15 @@ LesstifNetlistShow (int argc, char **argv, int x, int y)
 	  XmString item;
 	  int vis = 0;
 
-	  /* Select net first, 'true' causes pick_net() to be invoked */
+	  /* Select net first, 'True' causes pick_net() to be invoked */
 	  item = XmStringCreateLocalized (net->Name);
-	  XmListSelectItem (netlist_list, item, true);
+	  XmListSelectItem (netlist_list, item, True);
 	  XmListSetItem (netlist_list, item);
 	  XmStringFree (item);
 
 	  /* Now the netnode_list has the right contents */
 	  item = XmStringCreateLocalized (argv[0]);
-	  XmListSelectItem (netnode_list, item, false);
+	  XmListSelectItem (netnode_list, item, False);
 
 	  /*
 	   * Only force the item to the top if there are enough to scroll.
@@ -470,7 +470,7 @@ LesstifNetlistShow (int argc, char **argv, int x, int y)
 
 	      item = XmStringCreateLocalized (net->Name);
 	      XmListSetItem (netlist_list, item);
-	      XmListSelectItem (netlist_list, item, true);
+	      XmListSelectItem (netlist_list, item, True);
 	      XmStringFree (item);
 	    }
 	}
diff --git a/src/hid/lesstif/styles.c b/src/hid/lesstif/styles.c
index fb9d3b3..d3dcdaa 100644
--- a/src/hid/lesstif/styles.c
+++ b/src/hid/lesstif/styles.c
@@ -364,7 +364,7 @@ AdjustStyle (int argc, char **argv, int x, int y)
       xms_mil = XmStringCreateLocalized ("mil");
 
       n = 0;
-      stdarg (XmNautoUnmanage, false);
+      stdarg (XmNautoUnmanage, False);
       stdarg (XmNtitle, "Route Styles");
       style_dialog = XmCreateFormDialog (mainwind, "style", args, n);
 

commit 6714f5ff18afbf12c2a059482d747d15f250d68e
Author: Peter Clifton <pcjc2@xxxxxxxxx>
Commit: Peter Clifton <pcjc2@xxxxxxxxx>

    hid/lesstif: Use an intervening size_t casts to aovid compiler warnings
    
    This is to avoid the compiler warning us what we already know.. that we
    are passing an integer value cast into what might be a different sized
    pointer. (On 64 bit builds).

diff --git a/src/hid/lesstif/dialogs.c b/src/hid/lesstif/dialogs.c
index b3cc375..6c7a2de 100644
--- a/src/hid/lesstif/dialogs.c
+++ b/src/hid/lesstif/dialogs.c
@@ -1791,7 +1791,7 @@ lesstif_attributes_need_rows (int new_max)
       XtManageChild (attr_row[attr_max_rows].del);
       XtAddCallback (attr_row[attr_max_rows].del, XmNactivateCallback,
 		     (XtCallbackProc) attributes_delete_callback,
-		     (XtPointer) attr_max_rows);
+		     (XtPointer) (size_t) attr_max_rows);
 
       n = 0;
       stdarg (XmNresizeWidth, true);
@@ -1862,7 +1862,7 @@ attributes_delete_callback (Widget w, void *v, void *cbs)
   int i, n;
   Widget wn, wv;
 
-  n = (int) v;
+  n = (int) (size_t) v;
 
   wn = attr_row[n].w_name;
   wv = attr_row[n].w_value;

commit 2e46d5a7a626f703d868d25670af33b0c2afff17
Author: Peter Clifton <pcjc2@xxxxxxxxx>
Commit: Peter Clifton <pcjc2@xxxxxxxxx>

    hid/batch: Add some missing header files for prototypes

diff --git a/src/hid/batch/batch.c b/src/hid/batch/batch.c
index 8d53d8c..9715c09 100644
--- a/src/hid/batch/batch.c
+++ b/src/hid/batch/batch.c
@@ -8,10 +8,14 @@
 #include <stdarg.h>
 #include <stdlib.h>
 #include <string.h>
+#include <unistd.h>
 
 #include "global.h"
 #include "hid.h"
 #include "data.h"
+#include "misc.h"
+#include "hid.h"
+#include "../hidint.h"
 
 #include "hid/common/actions.h"
 #include "hid/common/hidinit.h"

commit 99ac52a605256bf60089d3177ff268d9fccf83ad
Author: Peter Clifton <pcjc2@xxxxxxxxx>
Commit: Peter Clifton <pcjc2@xxxxxxxxx>

    hid/common: Provide a header to define hid_parse_command_line()
    
    Avoids having each caller having to pull it in with an extern declaration.

diff --git a/src/Makefile.am b/src/Makefile.am
index ef72012..a0f1c50 100644
--- a/src/Makefile.am
+++ b/src/Makefile.am
@@ -143,6 +143,7 @@ PCB_SRCS = \
 	hid/common/actions.h \
 	hid/common/flags.c \
 	hid/common/hidinit.c \
+	hid/common/hidinit.h \
 	hid/common/hidnogui.c \
 	hid/common/extents.c \
 	hid/common/draw_helpers.c \
diff --git a/src/hid/batch/batch.c b/src/hid/batch/batch.c
index 6bc0e58..8d53d8c 100644
--- a/src/hid/batch/batch.c
+++ b/src/hid/batch/batch.c
@@ -14,6 +14,7 @@
 #include "data.h"
 
 #include "hid/common/actions.h"
+#include "hid/common/hidinit.h"
 
 #ifdef HAVE_LIBDMALLOC
 #include <dmalloc.h>
diff --git a/src/hid/common/hidinit.h b/src/hid/common/hidinit.h
new file mode 100644
index 0000000..bd1174f
--- /dev/null
+++ b/src/hid/common/hidinit.h
@@ -0,0 +1,6 @@
+#ifndef __HID_INIT_INCLUDED__
+#define __HID_INIT_INCLUDED__
+
+void hid_parse_command_line (int *argc, char ***argv);
+
+#endif
diff --git a/src/hid/gcode/gcode.c b/src/hid/gcode/gcode.c
index 7a52a7c..f1bdcea 100644
--- a/src/hid/gcode/gcode.c
+++ b/src/hid/gcode/gcode.c
@@ -60,6 +60,8 @@
 #include "trace.h"
 #include "decompose.h"
 
+#include "hid/common/hidinit.h"
+
 #ifdef HAVE_LIBDMALLOC
 #include <dmalloc.h>
 #endif
@@ -238,8 +240,6 @@ sort_drill (struct drill_struct *drill, int n_drill)
 
 /* *** Main export callback ************************************************ */
 
-extern void hid_parse_command_line (int *argc, char ***argv);
-
 static void
 gcode_parse_arguments (int *argc, char ***argv)
 {
diff --git a/src/hid/gerber/gerber.c b/src/hid/gerber/gerber.c
index e2d9c57..1f6341b 100644
--- a/src/hid/gerber/gerber.c
+++ b/src/hid/gerber/gerber.c
@@ -29,6 +29,7 @@
 #include "hid.h"
 #include "../hidint.h"
 #include "hid/common/draw_helpers.h"
+#include "hid/common/hidinit.h"
 
 #ifdef HAVE_LIBDMALLOC
 #include <dmalloc.h>
@@ -424,8 +425,6 @@ gerber_do_export (HID_Attr_Val * options)
   PCB->Flags = save_thindraw;
 }
 
-extern void hid_parse_command_line (int *argc, char ***argv);
-
 static void
 gerber_parse_arguments (int *argc, char ***argv)
 {
diff --git a/src/hid/lpr/lpr.c b/src/hid/lpr/lpr.c
index aa696be..ac3e2db 100644
--- a/src/hid/lpr/lpr.c
+++ b/src/hid/lpr/lpr.c
@@ -17,6 +17,7 @@
 #include "hid.h"
 #include "../hidint.h"
 #include "../ps/ps.h"
+#include "hid/common/hidinit.h"
 
 #ifdef HAVE_LIBDMALLOC
 #include <dmalloc.h>
@@ -97,8 +98,6 @@ lpr_do_export (HID_Attr_Val * options)
   fclose (f);
 }
 
-extern void hid_parse_command_line (int *argc, char ***argv);
-
 static void
 lpr_parse_arguments (int *argc, char ***argv)
 {
diff --git a/src/hid/nelma/nelma.c b/src/hid/nelma/nelma.c
index c53ce05..5f6ebc7 100644
--- a/src/hid/nelma/nelma.c
+++ b/src/hid/nelma/nelma.c
@@ -75,6 +75,8 @@
 
 #include <gd.h>
 
+#include "hid/common/hidinit.h"
+
 #ifdef HAVE_LIBDMALLOC
 #include <dmalloc.h>
 #endif
@@ -484,8 +486,6 @@ nelma_write_objects(FILE * out)
 
 /* *** Main export callback ************************************************ */
 
-extern void     hid_parse_command_line(int *argc, char ***argv);
-
 static void 
 nelma_parse_arguments(int *argc, char ***argv)
 {
diff --git a/src/hid/png/png.c b/src/hid/png/png.c
index 5c52768..32639c8 100644
--- a/src/hid/png/png.c
+++ b/src/hid/png/png.c
@@ -47,6 +47,8 @@
 /* the gd library which makes this all so easy */
 #include <gd.h>
 
+#include "hid/common/hidinit.h"
+
 #ifdef HAVE_LIBDMALLOC
 #include <dmalloc.h>
 #endif
@@ -876,8 +878,6 @@ png_do_export (HID_Attr_Val * options)
   gdImageDestroy (im);
 }
 
-extern void hid_parse_command_line (int *argc, char ***argv);
-
 static void
 png_parse_arguments (int *argc, char ***argv)
 {
diff --git a/src/hid/ps/eps.c b/src/hid/ps/eps.c
index 1b85b7d..83ce780 100644
--- a/src/hid/ps/eps.c
+++ b/src/hid/ps/eps.c
@@ -18,6 +18,7 @@
 #include "../hidint.h"
 #include "hid/common/draw_helpers.h"
 #include "../ps/ps.h"
+#include "hid/common/hidinit.h"
 
 #ifdef HAVE_LIBDMALLOC
 #include <dmalloc.h>
@@ -292,8 +293,6 @@ eps_do_export (HID_Attr_Val * options)
   fclose (f);
 }
 
-extern void hid_parse_command_line (int *argc, char ***argv);
-
 static void
 eps_parse_arguments (int *argc, char ***argv)
 {
diff --git a/src/hid/ps/ps.c b/src/hid/ps/ps.c
index 3e72b81..814e23e 100644
--- a/src/hid/ps/ps.c
+++ b/src/hid/ps/ps.c
@@ -22,6 +22,7 @@
 #include "hid/common/draw_helpers.h"
 #include "../ps/ps.h"
 #include "../../print.h"
+#include "hid/common/hidinit.h"
 
 #ifdef HAVE_LIBDMALLOC
 #include <dmalloc.h>
@@ -582,8 +583,6 @@ ps_do_export (HID_Attr_Val * options)
     }
 }
 
-extern void hid_parse_command_line (int *argc, char ***argv);
-
 static void
 ps_parse_arguments (int *argc, char ***argv)
 {

commit b2f7f75a375ca20350891f464283018677763a61
Author: Peter Clifton <pcjc2@xxxxxxxxx>
Commit: Peter Clifton <pcjc2@xxxxxxxxx>

    hid/common: Provide a header file to define print_actions()
    
    Avoids having each caller having to pull it in with an extern declaration.

diff --git a/src/Makefile.am b/src/Makefile.am
index e719268..ef72012 100644
--- a/src/Makefile.am
+++ b/src/Makefile.am
@@ -140,6 +140,7 @@ PCB_SRCS = \
 	vendor.c \
 	vendor.h \
 	hid/common/actions.c \
+	hid/common/actions.h \
 	hid/common/flags.c \
 	hid/common/hidinit.c \
 	hid/common/hidnogui.c \
diff --git a/src/hid/batch/batch.c b/src/hid/batch/batch.c
index cfa4e5a..6bc0e58 100644
--- a/src/hid/batch/batch.c
+++ b/src/hid/batch/batch.c
@@ -13,6 +13,8 @@
 #include "hid.h"
 #include "data.h"
 
+#include "hid/common/actions.h"
+
 #ifdef HAVE_LIBDMALLOC
 #include <dmalloc.h>
 #endif
diff --git a/src/hid/common/actions.h b/src/hid/common/actions.h
new file mode 100644
index 0000000..1cc6f24
--- /dev/null
+++ b/src/hid/common/actions.h
@@ -0,0 +1,7 @@
+
+#ifndef __HID_ACTIONS_INCLUDED__
+#define __HID_ACTIONS_INCLUDED__
+
+void print_actions (void);
+
+#endif
diff --git a/src/main.c b/src/main.c
index ba8c959..923e0ee 100644
--- a/src/main.c
+++ b/src/main.c
@@ -54,6 +54,8 @@
 #include "misc.h"
 #include "lrealpath.h"
 
+#include "hid/common/actions.h"
+
 /* This next one is so we can print the help messages. */
 #include "hid/hidint.h"
 
@@ -372,10 +374,6 @@ print_defaults ()
   exit (1);
 }
 
-/* in hid/common/actions.c */
-extern void print_actions ();
-
-
 #define SSET(F,D,N,H) { N, H, \
 	HID_String,  0, 0, { 0, D, 0 }, 0, &Settings.F }
 #define ISET(F,D,N,H) { N, H, \

commit 42930014efab78eb5ddb06ea1ef9053c4c7bb13e
Author: Peter Clifton <pcjc2@xxxxxxxxx>
Commit: Peter Clifton <pcjc2@xxxxxxxxx>

    Fix function prototypes and dummy return values for batch HID
    
    Most of these are dummy functions, but we should get the prototypes
    right! Also, return 0 from dummy functions which are supposed to return
    an integer.
    
    Fixes various compiler warnings.

diff --git a/src/hid/batch/batch.c b/src/hid/batch/batch.c
index 7db8a54..cfa4e5a 100644
--- a/src/hid/batch/batch.c
+++ b/src/hid/batch/batch.c
@@ -237,12 +237,12 @@ batch_fill_polygon (hidGC gc, int n_coords, int *x, int *y)
 }
 
 static void
-batch_fill_pcb_polygon (hidGC gc, PolygonType *poly)
+batch_fill_pcb_polygon (hidGC gc, PolygonType *poly, const BoxType *clip_box)
 {
 }
 
 static void
-batch_thindraw_pcb_polygon (hidGC gc, PolygonType *poly)
+batch_thindraw_pcb_polygon (hidGC gc, PolygonType *poly, const BoxType *clip_box)
 {
 }
 
@@ -393,10 +393,11 @@ batch_fileselect (const char *title, const char *descr,
 }
 
 static int
-batch_attribute_dialog (HID_Attribute * attrs,
-			int n_attrs, HID_Attr_Val * results,
-			const char *descr)
+batch_attribute_dialog (HID_Attribute * attrs_,
+			int n_attrs_, HID_Attr_Val * results_,
+			const char *title_, const char *descr_)
 {
+  return 0;
 }
 
 static void
@@ -411,9 +412,10 @@ batch_beep (void)
   fflush (stdout);
 }
 
-static void
-batch_progress (int so_far, int total, const char *message)
+static int
+batch_progress (int so_far_, int total_, const char *message_)
 {
+  return 0;
 }
 
 HID batch_gui = {

commit 86585c7eb9c35faa9ea310c241e80edb038c2055
Author: Peter Clifton <pcjc2@xxxxxxxxx>
Commit: Peter Clifton <pcjc2@xxxxxxxxx>

    HID: Make arguments to the prompt_for method const char *, not char *
    
    Avoids compiler warnings calling gui->prompt_for() with a const char *

diff --git a/src/hid.h b/src/hid.h
index dd34b8e..94734ba 100644
--- a/src/hid.h
+++ b/src/hid.h
@@ -468,7 +468,7 @@ typedef enum
     /* Prompts the user to enter a string, returns the string.  If
        default_string isn't NULL, the form is pre-filled with this
        value.  "msg" is like "Enter value:".  */
-    char *(*prompt_for) (char *msg_, char *default_string_);
+    char *(*prompt_for) (const char *msg_, const char *default_string_);
 
     /* Prompts the user for a filename or directory name.  For GUI
        HID's this would mean a file select dialog box.  The 'flags'
diff --git a/src/hid/batch/batch.c b/src/hid/batch/batch.c
index f3b7d3c..7db8a54 100644
--- a/src/hid/batch/batch.c
+++ b/src/hid/batch/batch.c
@@ -363,7 +363,7 @@ batch_report_dialog (char *title, char *msg)
 }
 
 static char *
-batch_prompt_for (char *msg, char *default_string)
+batch_prompt_for (const char *msg, const char *default_string)
 {
   static char buf[1024];
   if (default_string)
diff --git a/src/hid/common/hidnogui.c b/src/hid/common/hidnogui.c
index d5dc9e1..6111ec3 100644
--- a/src/hid/common/hidnogui.c
+++ b/src/hid/common/hidnogui.c
@@ -287,7 +287,7 @@ nogui_report_dialog (char *title, char *msg)
 }
 
 static char *
-nogui_prompt_for (char *msg, char *default_string)
+nogui_prompt_for (const char *msg, const char *default_string)
 {
   static char buf[1024];
   if (default_string)
diff --git a/src/hid/gtk/gtkhid-main.c b/src/hid/gtk/gtkhid-main.c
index 7d59672..a3947d0 100644
--- a/src/hid/gtk/gtkhid-main.c
+++ b/src/hid/gtk/gtkhid-main.c
@@ -867,7 +867,7 @@ ghid_report_dialog (char *title, char *msg)
 }
 
 char *
-ghid_prompt_for (char *msg, char *default_string)
+ghid_prompt_for (const char *msg, const char *default_string)
 {
   char *rv;
 
diff --git a/src/hid/gtk/gui-dialog.c b/src/hid/gtk/gui-dialog.c
index ec91233..1f6b11a 100644
--- a/src/hid/gtk/gui-dialog.c
+++ b/src/hid/gtk/gui-dialog.c
@@ -46,7 +46,7 @@ RCSID ("$Id$");
 
 /* ---------------------------------------------- */
 gchar *
-ghid_dialog_input (gchar * prompt, gchar * initial)
+ghid_dialog_input (const char * prompt, const char * initial)
 {
   GtkWidget *dialog, *vbox, *label, *entry;
   gchar *string;
diff --git a/src/hid/gtk/gui.h b/src/hid/gtk/gui.h
index 7686106..4ad6cdc 100644
--- a/src/hid/gtk/gui.h
+++ b/src/hid/gtk/gui.h
@@ -332,7 +332,7 @@ int ghid_dialog_close_confirm (void);
 #define GUI_DIALOG_CLOSE_CONFIRM_NOSAVE 1
 #define GUI_DIALOG_CLOSE_CONFIRM_SAVE   2
 gint ghid_dialog_confirm_all (gchar * message);
-gchar *ghid_dialog_input (gchar * prompt, gchar * initial);
+gchar *ghid_dialog_input (const char * prompt, const char * initial);
 void ghid_dialog_about (void);
 
 char * ghid_fileselect (const char *, const char *, char *, char *, const char *, int);
diff --git a/src/hid/lesstif/dialogs.c b/src/hid/lesstif/dialogs.c
index 544a718..b3cc375 100644
--- a/src/hid/lesstif/dialogs.c
+++ b/src/hid/lesstif/dialogs.c
@@ -544,7 +544,7 @@ lesstif_fileselect (const char *title, const char *descr,
 		    const char *history_tag, int flags)
 {
 
-  return lesstif_prompt_for ((char *)title, default_file);
+  return lesstif_prompt_for (title, default_file);
 }
 
 /* ------------------------------------------------------------ */
@@ -553,7 +553,7 @@ static Widget prompt_dialog = 0;
 static Widget prompt_label, prompt_text;
 
 char *
-lesstif_prompt_for (char *msg, char *default_string)
+lesstif_prompt_for (const char *msg, const char *default_string)
 {
   char *rv;
   XmString xs;
@@ -592,7 +592,7 @@ lesstif_prompt_for (char *msg, char *default_string)
   xs = XmStringCreateLocalized ((char *)msg);
   stdarg (XmNlabelString, xs);
   XtSetValues (prompt_label, args, n);
-  XmTextSetString (prompt_text, default_string);
+  XmTextSetString (prompt_text, (char *)default_string);
   XmTextSetCursorPosition (prompt_text, strlen (default_string));
   wait_for_dialog (prompt_dialog);
   rv = XmTextGetString (prompt_text);
diff --git a/src/hid/lesstif/lesstif.h b/src/hid/lesstif/lesstif.h
index 54e4ced..3bc822b 100644
--- a/src/hid/lesstif/lesstif.h
+++ b/src/hid/lesstif/lesstif.h
@@ -50,7 +50,7 @@ extern void lesstif_insert_style_buttons (Widget menu);
 extern void lesstif_styles_update_values ();
 extern void lesstif_update_layer_groups ();
 extern void lesstif_update_status_line ();
-extern char *lesstif_prompt_for (char *, char *);
+extern char *lesstif_prompt_for (const char *, const char *);
 extern char *lesstif_fileselect (const char *, const char *,
 				 char *, char *,
 				 const char *, int);

commit 2265df977e20edf832f56c74e78fca1e15b45555
Author: Peter Clifton <pcjc2@xxxxxxxxx>
Commit: Peter Clifton <pcjc2@xxxxxxxxx>

    Rename "r" variables used in calls to GetValue() to be more descriptive
    
    A purely cosmetic change.

diff --git a/src/action.c b/src/action.c
index 8d5931a..b8707d1 100644
--- a/src/action.c
+++ b/src/action.c
@@ -7012,7 +7012,8 @@ static int
 parse_layout_attribute_units (char *name, int def)
 {
   const char *as, *units = NULL;
-  int n = 0, v, r;
+  int n = 0, v;
+  bool r;
 
   as = AttributeGet (PCB, name);
   if (!as)
@@ -7653,7 +7654,7 @@ ActionImport (int argc, char **argv, int x, int y)
 	}
       else if (ys)
 	{
-	  int r;
+	  bool r;
 	  x = GetValue (xs, units, &r);
 	  y = GetValue (ys, units, &r);
 	}

commit 05f663f3905d3dde859fefa1f614c29d67428539
Author: Peter Clifton <pcjc2@xxxxxxxxx>
Commit: Peter Clifton <pcjc2@xxxxxxxxx>

    Change unmodifed parameters to GetValue to const char *
    
    Silences some compiler warnings in action.c

diff --git a/src/misc.c b/src/misc.c
index 76b05c0..b1d4304 100644
--- a/src/misc.c
+++ b/src/misc.c
@@ -108,7 +108,7 @@ static struct
  * bool variable absolute to false if it leads with a +/- character
  */
 float
-GetValue (char *val, char *units, bool * absolute)
+GetValue (const char *val, const char *units, bool * absolute)
 {
   double value;
   int n = -1;
diff --git a/src/misc.h b/src/misc.h
index bb88a21..82bd194 100644
--- a/src/misc.h
+++ b/src/misc.h
@@ -74,7 +74,7 @@ BoxTypePtr GetArcEnds (ArcTypePtr);
 void ChangeArcAngles (LayerTypePtr, ArcTypePtr, long int, long int);
 char *UniqueElementName (DataTypePtr, char *);
 void AttachForCopy (LocationType, LocationType);
-float GetValue (char *, char *, bool *);
+float GetValue (const char *, const char *, bool *);
 int FileExists (const char *);
 char *Concat (const char *, ...);	/* end with NULL */
 

commit 7fa6e8145b3a9e2b85b42a2bae12d55fe0005ae1
Author: Peter Clifton <pcjc2@xxxxxxxxx>
Commit: Peter Clifton <pcjc2@xxxxxxxxx>

    autoroute.c: #if 0 out an unused static function add_clearance()
    
    Silences compiler warning.

diff --git a/src/autoroute.c b/src/autoroute.c
index ea97d01..9ccab97 100644
--- a/src/autoroute.c
+++ b/src/autoroute.c
@@ -3428,6 +3428,7 @@ RD_DrawManhattanLine (routedata_t * rd,
 }
 
 /* for smoothing, don't pack traces to min clearance gratuitously */
+#if 0
 static void
 add_clearance (CheapPointType * nextpoint, const BoxType * b)
 {
@@ -3464,6 +3465,7 @@ add_clearance (CheapPointType * nextpoint, const BoxType * b)
 	nextpoint->Y = (b->Y1 + b->Y2) / 2;
     }
 }
+#endif
 
 /* This back-traces the expansion boxes along the best path
  * it draws the lines that will make the actual path.

commit ec76a0d17c1baea2dd83a6a67b6fe48aee74b547
Author: Peter Clifton <pcjc2@xxxxxxxxx>
Commit: Peter Clifton <pcjc2@xxxxxxxxx>

    djopt.c: #if 0 out an unused static function nudge_corner()
    
    Silences a compiler warning.

diff --git a/src/djopt.c b/src/djopt.c
index 800e574..b5d9c39 100644
--- a/src/djopt.c
+++ b/src/djopt.c
@@ -2491,6 +2491,7 @@ dump_all ()
 }
 #endif
 
+#if 0
 static void
 nudge_corner (corner_s * c, int dx, int dy, corner_s * prev_corner)
 {
@@ -2511,6 +2512,7 @@ nudge_corner (corner_s * c, int dx, int dy, corner_s * prev_corner)
 	nudge_corner (oc, 0, dy, c);
     }
 }
+#endif
 
 static line_s *
 choose_example_line (corner_s * c1, corner_s * c2)

commit d5fd3e348da36c4fb10100b0cc5e218069c309c9
Author: Peter Clifton <pcjc2@xxxxxxxxx>
Commit: Peter Clifton <pcjc2@xxxxxxxxx>

    buffer.c: Declare variables before code in ActionFreeRotateBuffer()
    
    Avoids compiler warning "ISO C90 forbids mixed declarations and code"

diff --git a/src/buffer.c b/src/buffer.c
index bec918f..f9d6f5a 100644
--- a/src/buffer.c
+++ b/src/buffer.c
@@ -1449,9 +1449,10 @@ angle is given, the user is prompted for one.
 int
 ActionFreeRotateBuffer(int argc, char **argv, int x, int y)
 {
-  HideCrosshair(false);
   char *angle_s;
 
+  HideCrosshair(false);
+
   if (argc < 1)
     angle_s = gui->prompt_for ("Enter Rotation (degrees, CCW):", "0");
   else

commit a17c8a99d84ba8408ffe6173813a982016545cba
Author: Peter Clifton <pcjc2@xxxxxxxxx>
Commit: Peter Clifton <pcjc2@xxxxxxxxx>

    change.c: Remove unused variable in ChangeElementText()

diff --git a/src/change.c b/src/change.c
index 5546f1f..df7f454 100644
--- a/src/change.c
+++ b/src/change.c
@@ -1034,8 +1034,6 @@ ChangeElementText (PCBType *pcb, DataType *data, ElementTypePtr Element, int whi
 static void *
 ChangeElementName (ElementTypePtr Element)
 {
-  char *old = ELEMENT_NAME (PCB, Element);
-
   if (TEST_FLAG (LOCKFLAG, &Element->Name[0]))
     return (NULL);
   if (NAME_INDEX (PCB) == NAMEONPCB_INDEX)

commit e4a4a0740d6b648ce5026bef1261726037f90163
Author: Peter Clifton <pcjc2@xxxxxxxxx>
Commit: Peter Clifton <pcjc2@xxxxxxxxx>

    Remove unused variables in ActionElementList() and ActionImport()

diff --git a/src/action.c b/src/action.c
index ba9ca44..8d5931a 100644
--- a/src/action.c
+++ b/src/action.c
@@ -7095,7 +7095,6 @@ ActionElementList (int argc, char **argv, int x, int y)
   if (!e)
     {
       int nx, ny, d;
-      char *as;
 
 #ifdef DEBUG
       printf("  ... Footprint not on board, need to add it.\n");
@@ -7605,7 +7604,6 @@ ActionImport (int argc, char **argv, int x, int y)
   if (mode && strcasecmp (mode, "setdisperse") == 0)
     {
       const char *ds, *units;
-      int d, r;
       char buf[50];
 
       ds = ARG (1);

commit 9dab8d5519bcb752d91d3e4647bbc2356ed80830
Author: Peter Clifton <pcjc2@xxxxxxxxx>
Commit: Peter Clifton <pcjc2@xxxxxxxxx>

    Add missing return value in ActionImport()

diff --git a/src/action.c b/src/action.c
index f52fcf4..ba9ca44 100644
--- a/src/action.c
+++ b/src/action.c
@@ -7643,7 +7643,7 @@ ActionImport (int argc, char **argv, int x, int y)
 	{
 	  AttributeRemove (PCB, "import::newX");
 	  AttributeRemove (PCB, "import::newY");
-	  return;
+	  return 0;
 	}
       else if (strcasecmp (xs, "mark") == 0)
 	{

commit cadcc01668cd9de9629992bcfc9d28f910738662
Author: Peter Clifton <pcjc2@xxxxxxxxx>
Commit: Peter Clifton <pcjc2@xxxxxxxxx>

    Silence used function warning for __r_tree_is_good() (Non-debug builds)
    
    __r_tree_is_good() and its helper functions are only used when debugging,
    and are called from assert() macros. If "NDEBUG" is defined, these expand
    to nothing, and the function is not called.
    
    Wrap __r_tree_is_good() and its helper, __r_tree_node_is_good() with
    #ifndef NDEBUG

diff --git a/src/rtree.c b/src/rtree.c
index a6fe712..f44672c 100644
--- a/src/rtree.c
+++ b/src/rtree.c
@@ -104,6 +104,7 @@ struct rtree_node
   } u;
 };
 
+#ifndef NDEBUG
 #ifdef SLOW_ASSERTS
 static int
 __r_node_is_good (struct rtree_node *node)
@@ -197,7 +198,6 @@ __r_node_is_good (struct rtree_node *node)
   return 1;
 }
 
-
 /* check the whole tree from this node down for consistency */
 static bool
 __r_tree_is_good (struct rtree_node *node)
@@ -218,6 +218,8 @@ __r_tree_is_good (struct rtree_node *node)
   return 1;
 }
 #endif
+#endif
+
 #ifndef NDEBUG
 /* print out the tree */
 void

commit 8a764804b6c1af050552ba79ec284a2021d55157
Author: Peter Clifton <pcjc2@xxxxxxxxx>
Commit: Peter Clifton <pcjc2@xxxxxxxxx>

    file.c: The "elapsed" variable in LoadPCB is debugging only
    
    Silence compiler warning by moving it inside the #ifdef DEBUG

diff --git a/src/file.c b/src/file.c
index 6893379..aff5073 100644
--- a/src/file.c
+++ b/src/file.c
@@ -352,8 +352,8 @@ LoadPCB (char *Filename)
 {
   PCBTypePtr newPCB = CreateNewPCB (false);
   bool units_mm;
-  double elapsed;
 #ifdef DEBUG
+  double elapsed;
   clock_t start, end;
 
   start = clock ();

commit f9119256366eb114f4dd30a62fa1aa95cd9ffb72
Author: Peter Clifton <pcjc2@xxxxxxxxx>
Commit: Peter Clifton <pcjc2@xxxxxxxxx>

    flags.c: Avoid compiler warning when casting our OffsetOf value
    
    Strictly, our OffsetOf calculation "could" return a number as large as the
    pointer size on the system - so the compiler will complain when we squash
    it directly into an int. Casting via a size_t will avoid the warning.
    
    Our structure offsets are small, so this is safe - if somewhat ugly.

diff --git a/src/flags.c b/src/flags.c
index c33cfb6..499e59e 100644
--- a/src/flags.c
+++ b/src/flags.c
@@ -163,7 +163,12 @@ FlagLayerActive (int n)
   return current_layer == n;
 }
 
-#define OffsetOf(a,b) (int)(&(((a *)0)->b))
+/* The cast to (int) is ONLY valid because we know we are
+ * taking offsets on structures where the offset will fit
+ * in an integer variable. It silences compile warnings on
+ * 64bit machines.
+ */
+#define OffsetOf(a,b) (int)(size_t)(&(((a *)0)->b))
 
 HID_Flag flags_flag_list[] = {
   {"style", FlagCurrentStyle, 0},

commit 8f3cf398616a634cb85c40b7295dcfec5fbe70e5
Author: Peter Clifton <pcjc2@xxxxxxxxx>
Commit: Peter Clifton <pcjc2@xxxxxxxxx>

    Toporouter: Comment unused debug variable
    
    Silences compiler warning

diff --git a/src/toporouter.c b/src/toporouter.c
index 0ad26b5..41fd4b1 100644
--- a/src/toporouter.c
+++ b/src/toporouter.c
@@ -2577,11 +2577,10 @@ check_cons_continuation:
   }
   i = l->constraints;
   while (i) {
-    
-    toporouter_constraint_t *c1 = TOPOROUTER_CONSTRAINT(i->data);
-    
-  //  printf("adding cons: "); print_constraint(c1);
-    
+
+    // toporouter_constraint_t *c1 = TOPOROUTER_CONSTRAINT(i->data);
+    // printf("adding cons: "); print_constraint(c1);
+
     GSList *conflicts = gts_delaunay_add_constraint (l->surface, i->data);
     GSList *j = conflicts;
     while(j) {

commit 4f81df61732f5328a0d66cabc53503fd745c8bc9
Author: Peter Clifton <pcjc2@xxxxxxxxx>
Commit: Peter Clifton <pcjc2@xxxxxxxxx>

    gts: Comment some unused variables left as placeholders
    
    Silences compiler warnings

diff --git a/src/gts/pgraph.c b/src/gts/pgraph.c
index 2c13c1e..6d1f619 100644
--- a/src/gts/pgraph.c
+++ b/src/gts/pgraph.c
@@ -30,8 +30,8 @@ static void gnode_split_destroy (GtsObject * object)
     gts_object_destroy (GTS_OBJECT (ns->n));
   }
   else {
-    GtsGNode * n1 = GTS_GNODE_SPLIT_N1 (ns);
-    GtsGNode * n2 = GTS_GNODE_SPLIT_N2 (ns);
+    /* GtsGNode * n1 = GTS_GNODE_SPLIT_N1 (ns); */
+    /* GtsGNode * n2 = GTS_GNODE_SPLIT_N2 (ns); */
 
     g_warning ("Memory deallocation for GtsGNodeSplit not fully implemented yet: memory leak!");
   }

commit 0c66ee758d318111b5ec867f0ba89f4fab0a6601
Author: Peter Clifton <pcjc2@xxxxxxxxx>
Commit: Peter Clifton <pcjc2@xxxxxxxxx>

    gts: Add cast to silence compiler warning

diff --git a/src/gts/edge.c b/src/gts/edge.c
index 47754de..fde7d87 100644
--- a/src/gts/edge.c
+++ b/src/gts/edge.c
@@ -100,7 +100,7 @@ void gts_edge_remove(GtsEdge *edge)
 {
   edge->segment.v1->segments = g_slist_remove(edge->segment.v1->segments, &edge->segment);
   edge->segment.v2->segments = g_slist_remove(edge->segment.v2->segments, &edge->segment);
-  edge_destroy(edge); 
+  edge_destroy(GTS_OBJECT (edge));
 }
 
 /**

commit 3c47897d8c8d151ae76203f1bb49270d9a2d747e
Author: Peter Clifton <pcjc2@xxxxxxxxx>
Commit: Peter Clifton <pcjc2@xxxxxxxxx>

    *.l: Add #define YY_NO_INPUT to avoid defining unused "input()" function
    
    Silences compiler warnings

diff --git a/src/parse_l.l b/src/parse_l.l
index b1b67a8..c9d96c8 100644
--- a/src/parse_l.l
+++ b/src/parse_l.l
@@ -62,6 +62,8 @@ RCSID("$Id$");
 #include "parse_l.h"
 #include "parse_y.h"
 
+#define YY_NO_INPUT
+
 /* ---------------------------------------------------------------------------
  * some shared parser identifiers
  */
diff --git a/src/res_lex.l b/src/res_lex.l
index 0525aed..5e08666 100644
--- a/src/res_lex.l
+++ b/src/res_lex.l
@@ -20,6 +20,7 @@
 
 RCSID("$Id$");
 
+#define YY_NO_INPUT
 #define YY_INPUT(buf,result,max_size) { result = res_parse_getchars(buf, max_size); }
  
 #ifdef FLEX_SCANNER




_______________________________________________
geda-cvs mailing list
geda-cvs@xxxxxxxxxxxxxx
http://www.seul.org/cgi-bin/mailman/listinfo/geda-cvs
diff --git a/src/action.c b/src/action.c
index b8707d1..34d54e2 100644
--- a/src/action.c
+++ b/src/action.c
@@ -2211,24 +2211,25 @@ ActionSetValue (int argc, char **argv, int x, int y)
   char *function = ARG (0);
   char *val = ARG (1);
   char *units = ARG (2);
-  bool r;			/* flag for 'relative' value */
+  bool absolute;			/* flag for 'absolute' value */
   float value;
   int err = 0;
 
   if (function && val)
     {
       HideCrosshair (true);
-      value = GetValue (val, units, &r);
+      value = GetValue (val, units, &absolute);
       switch (GetFunctionID (function))
 	{
 	case F_ViaDrillingHole:
-	  SetViaDrillingHole (r ? value : value + Settings.ViaDrillingHole,
+	  SetViaDrillingHole (absolute ? value :
+                                value + Settings.ViaDrillingHole,
 			      false);
 	  hid_action ("RouteStylesChanged");
 	  break;
 
 	case F_Grid:
-	  if (!r)
+	  if (!absolute)
 	    {
 	      if ((value == (int) value && PCB->Grid == (int) PCB->Grid)
 		  || (value != (int) value && PCB->Grid != (int) PCB->Grid)
@@ -2256,20 +2257,20 @@ ActionSetValue (int argc, char **argv, int x, int y)
 
 	case F_LineSize:
 	case F_Line:
-	  SetLineSize (r ? value : value + Settings.LineThickness);
+	  SetLineSize (absolute ? value : value + Settings.LineThickness);
 	  hid_action ("RouteStylesChanged");
 	  break;
 
 	case F_Via:
 	case F_ViaSize:
-	  SetViaSize (r ? value : value + Settings.ViaThickness, false);
+	  SetViaSize (absolute ? value : value + Settings.ViaThickness, false);
 	  hid_action ("RouteStylesChanged");
 	  break;
 
 	case F_Text:
 	case F_TextScale:
 	  value /= 45;
-	  SetTextScale (r ? value : value + Settings.TextScale);
+	  SetTextScale (absolute ? value : value + Settings.TextScale);
 	  break;
 	default:
 	  err = 1;
@@ -4070,12 +4071,12 @@ ActionChangeSize (int argc, char **argv, int x, int y)
   char *function = ARG (0);
   char *delta = ARG (1);
   char *units = ARG (2);
-  bool r;			/* indicates if absolute size is given */
+  bool absolute;			/* indicates if absolute size is given */
   float value;
 
   if (function && delta)
     {
-      value = GetValue (delta, units, &r);
+      value = GetValue (delta, units, &absolute);
       HideCrosshair (true);
       switch (GetFunctionID (function))
 	{
@@ -4089,54 +4090,54 @@ ActionChangeSize (int argc, char **argv, int x, int y)
 			       &ptr1, &ptr2, &ptr3)) != NO_TYPE)
 	      if (TEST_FLAG (LOCKFLAG, (PinTypePtr) ptr2))
 		Message (_("Sorry, the object is locked\n"));
-	    if (ChangeObjectSize (type, ptr1, ptr2, ptr3, value, r))
+	    if (ChangeObjectSize (type, ptr1, ptr2, ptr3, value, absolute))
 	      SetChangedFlag (true);
 	    break;
 	  }
 
 	case F_SelectedVias:
-	  if (ChangeSelectedSize (VIA_TYPE, value, r))
+	  if (ChangeSelectedSize (VIA_TYPE, value, absolute))
 	    SetChangedFlag (true);
 	  break;
 
 	case F_SelectedPins:
-	  if (ChangeSelectedSize (PIN_TYPE, value, r))
+	  if (ChangeSelectedSize (PIN_TYPE, value, absolute))
 	    SetChangedFlag (true);
 	  break;
 
 	case F_SelectedPads:
-	  if (ChangeSelectedSize (PAD_TYPE, value, r))
+	  if (ChangeSelectedSize (PAD_TYPE, value, absolute))
 	    SetChangedFlag (true);
 	  break;
 
 	case F_SelectedArcs:
-	  if (ChangeSelectedSize (ARC_TYPE, value, r))
+	  if (ChangeSelectedSize (ARC_TYPE, value, absolute))
 	    SetChangedFlag (true);
 	  break;
 
 	case F_SelectedLines:
-	  if (ChangeSelectedSize (LINE_TYPE, value, r))
+	  if (ChangeSelectedSize (LINE_TYPE, value, absolute))
 	    SetChangedFlag (true);
 	  break;
 
 	case F_SelectedTexts:
-	  if (ChangeSelectedSize (TEXT_TYPE, value, r))
+	  if (ChangeSelectedSize (TEXT_TYPE, value, absolute))
 	    SetChangedFlag (true);
 	  break;
 
 	case F_SelectedNames:
-	  if (ChangeSelectedSize (ELEMENTNAME_TYPE, value, r))
+	  if (ChangeSelectedSize (ELEMENTNAME_TYPE, value, absolute))
 	    SetChangedFlag (true);
 	  break;
 
 	case F_SelectedElements:
-	  if (ChangeSelectedSize (ELEMENT_TYPE, value, r))
+	  if (ChangeSelectedSize (ELEMENT_TYPE, value, absolute))
 	    SetChangedFlag (true);
 	  break;
 
 	case F_Selected:
 	case F_SelectedObjects:
-	  if (ChangeSelectedSize (CHANGESIZE_TYPES, value, r))
+	  if (ChangeSelectedSize (CHANGESIZE_TYPES, value, absolute))
 	    SetChangedFlag (true);
 	  break;
 	}
@@ -4164,12 +4165,12 @@ ActionChange2ndSize (int argc, char **argv, int x, int y)
   char *function = ARG (0);
   char *delta = ARG (1);
   char *units = ARG (2);
-  bool r;
+  bool absolute;
   float value;
 
   if (function && delta)
     {
-      value = GetValue (delta, units, &r);
+      value = GetValue (delta, units, &absolute);
       HideCrosshair (true);
       switch (GetFunctionID (function))
 	{
@@ -4183,23 +4184,23 @@ ActionChange2ndSize (int argc, char **argv, int x, int y)
 		 SearchScreen (x, y, CHANGE2NDSIZE_TYPES,
 			       &ptr1, &ptr2, &ptr3)) != NO_TYPE)
 	      if (ChangeObject2ndSize
-		  (type, ptr1, ptr2, ptr3, value, r, true))
+		  (type, ptr1, ptr2, ptr3, value, absolute, true))
 		SetChangedFlag (true);
 	    break;
 	  }
 
 	case F_SelectedVias:
-	  if (ChangeSelected2ndSize (VIA_TYPE, value, r))
+	  if (ChangeSelected2ndSize (VIA_TYPE, value, absolute))
 	    SetChangedFlag (true);
 	  break;
 
 	case F_SelectedPins:
-	  if (ChangeSelected2ndSize (PIN_TYPE, value, r))
+	  if (ChangeSelected2ndSize (PIN_TYPE, value, absolute))
 	    SetChangedFlag (true);
 	  break;
 	case F_Selected:
 	case F_SelectedObjects:
-	  if (ChangeSelected2ndSize (PIN_TYPES, value, r))
+	  if (ChangeSelected2ndSize (PIN_TYPES, value, absolute))
 	    SetChangedFlag (true);
 	  break;
 	}
@@ -4233,12 +4234,12 @@ ActionChangeClearSize (int argc, char **argv, int x, int y)
   char *function = ARG (0);
   char *delta = ARG (1);
   char *units = ARG (2);
-  bool r;
+  bool absolute;
   float value;
 
   if (function && delta)
     {
-      value = 2 * GetValue (delta, units, &r);
+      value = 2 * GetValue (delta, units, &absolute);
       HideCrosshair (true);
       switch (GetFunctionID (function))
 	{
@@ -4252,33 +4253,33 @@ ActionChangeClearSize (int argc, char **argv, int x, int y)
 		 SearchScreen (x, y,
 			       CHANGECLEARSIZE_TYPES, &ptr1, &ptr2,
 			       &ptr3)) != NO_TYPE)
-	      if (ChangeObjectClearSize (type, ptr1, ptr2, ptr3, value, r))
+	      if (ChangeObjectClearSize (type, ptr1, ptr2, ptr3, value, absolute))
 		SetChangedFlag (true);
 	    break;
 	  }
 	case F_SelectedVias:
-	  if (ChangeSelectedClearSize (VIA_TYPE, value, r))
+	  if (ChangeSelectedClearSize (VIA_TYPE, value, absolute))
 	    SetChangedFlag (true);
 	  break;
 	case F_SelectedPads:
-	  if (ChangeSelectedClearSize (PAD_TYPE, value, r))
+	  if (ChangeSelectedClearSize (PAD_TYPE, value, absolute))
 	    SetChangedFlag (true);
 	  break;
 	case F_SelectedPins:
-	  if (ChangeSelectedClearSize (PIN_TYPE, value, r))
+	  if (ChangeSelectedClearSize (PIN_TYPE, value, absolute))
 	    SetChangedFlag (true);
 	  break;
 	case F_SelectedLines:
-	  if (ChangeSelectedClearSize (LINE_TYPE, value, r))
+	  if (ChangeSelectedClearSize (LINE_TYPE, value, absolute))
 	    SetChangedFlag (true);
 	  break;
 	case F_SelectedArcs:
-	  if (ChangeSelectedClearSize (ARC_TYPE, value, r))
+	  if (ChangeSelectedClearSize (ARC_TYPE, value, absolute))
 	    SetChangedFlag (true);
 	  break;
 	case F_Selected:
 	case F_SelectedObjects:
-	  if (ChangeSelectedClearSize (CHANGECLEARSIZE_TYPES, value, r))
+	  if (ChangeSelectedClearSize (CHANGECLEARSIZE_TYPES, value, absolute))
 	    SetChangedFlag (true);
 	  break;
 	}
@@ -4309,7 +4310,7 @@ ActionMinMaskGap (int argc, char **argv, int x, int y)
   char *function = ARG (0);
   char *delta = ARG (1);
   char *units = ARG (2);
-  bool r;
+  bool absolute;
   int value;
   int flags;
 
@@ -4323,7 +4324,7 @@ ActionMinMaskGap (int argc, char **argv, int x, int y)
       delta = function;
       flags = 0;
     }
-  value = 2 * GetValue (delta, units, &r);
+  value = 2 * GetValue (delta, units, &absolute);
 
   HideCrosshair (true);
   SaveUndoSerialNumber ();
@@ -4393,7 +4394,7 @@ ActionMinClearGap (int argc, char **argv, int x, int y)
   char *function = ARG (0);
   char *delta = ARG (1);
   char *units = ARG (2);
-  bool r;
+  bool absolute;
   int value;
   int flags;
 
@@ -4407,7 +4408,7 @@ ActionMinClearGap (int argc, char **argv, int x, int y)
       delta = function;
       flags = 0;
     }
-  value = 2 * GetValue (delta, units, &r);
+  value = 2 * GetValue (delta, units, &absolute);
 
   HideCrosshair (true);
   SaveUndoSerialNumber ();
@@ -6137,7 +6138,7 @@ ActionPasteBuffer (int argc, char **argv, int x, int y)
 	  {
 	    static int oldx = 0, oldy = 0;
 	    int x, y;
-	    bool r;
+	    bool absolute;
 
 	    if (argc == 1)
 	      {
@@ -6145,11 +6146,11 @@ ActionPasteBuffer (int argc, char **argv, int x, int y)
 	      }
 	    else if (argc == 3 || argc == 4)
 	      {
-		x = GetValue (ARG (1), ARG (3), &r);
-		if (!r)
+		x = GetValue (ARG (1), ARG (3), &absolute);
+		if (!absolute)
 		  x += oldx;
-		y = GetValue (ARG (2), ARG (3), &r);
-		if (!r)
+		y = GetValue (ARG (2), ARG (3), &absolute);
+		if (!absolute)
 		  y += oldy;
 	      }
 	    else
@@ -6512,12 +6513,12 @@ ActionMoveObject (int argc, char **argv, int x, int y)
   char *y_str = ARG (1);
   char *units = ARG (2);
   LocationType nx, ny;
-  bool r1, r2;
+  bool absolute1, absolute2;
   void *ptr1, *ptr2, *ptr3;
   int type;
 
-  ny = GetValue (y_str, units, &r1);
-  nx = GetValue (x_str, units, &r2);
+  ny = GetValue (y_str, units, &absolute1);
+  nx = GetValue (x_str, units, &absolute2);
 
   type = SearchScreen (x, y, MOVE_TYPES, &ptr1, &ptr2, &ptr3);
   if (type == NO_TYPE)
@@ -6525,9 +6526,9 @@ ActionMoveObject (int argc, char **argv, int x, int y)
       Message (_("Nothing found under crosshair\n"));
       return 1;
     }
-  if (r1)
+  if (absolute1)
     nx -= x;
-  if (r2)
+  if (absolute2)
     ny -= y;
   Crosshair.AttachedObject.RubberbandN = 0;
   if (TEST_FLAG (RUBBERBANDFLAG, PCB))
@@ -7013,7 +7014,7 @@ parse_layout_attribute_units (char *name, int def)
 {
   const char *as, *units = NULL;
   int n = 0, v;
-  bool r;
+  bool absolute;
 
   as = AttributeGet (PCB, name);
   if (!as)
@@ -7023,7 +7024,7 @@ parse_layout_attribute_units (char *name, int def)
   units = as + n;
   if (! *units)
     units = NULL;
-  v = GetValue (as, units, &r);
+  v = GetValue (as, units, &absolute);
   return v;
 }
 
@@ -7654,9 +7655,9 @@ ActionImport (int argc, char **argv, int x, int y)
 	}
       else if (ys)
 	{
-	  bool r;
-	  x = GetValue (xs, units, &r);
-	  y = GetValue (ys, units, &r);
+	  bool absolute;
+	  x = GetValue (xs, units, &absolute);
+	  y = GetValue (ys, units, &absolute);
 	}
       else
 	{

commit 5f9832e8b50bd56dd56d28391dc6cb8c7be8a0d9
Author: Peter Clifton <pcjc2@xxxxxxxxx>
Commit: Peter Clifton <pcjc2@xxxxxxxxx>

    action.c: Fix data types in GetValue calls
    
    We passed an (int *) rather than a (bool *) in ActionImport() and
    parse_layout_attribute_units()
